;; -*-emacs-lisp-*-

;; Author: K. Arun <kar@myrealbox.com>
;; File  : $HOME/.emacs
;; Revision: $Id: .emacs,v 1.25 2000/06/17 07:07:44 kar Exp $


;; Paths
(setq load-path (cons "/usr/local/share/emacs/site-lisp" load-path))
(setq load-path (cons "/home/kar/lisp/" load-path))
(setq Info-default-directory-list '("~/lisp/info"
				    "/usr/local/lib/info"
				    "/usr/local/info"
				    "/usr/info"
				    "/usr/share/info"
				    ))

;; Key bindings
(global-set-key [f1] 'manual-entry)
(global-set-key [f2] 'info)
;(global-set-key [f3] 'vm)
(global-set-key [f3] 'gnus)
(global-set-key [f4] 'kill-buffer)
(global-set-key [f5] 'find-file)
(global-set-key [f6] 'comment-region)
(global-set-key [f7] 'delete-frame)
(global-set-key [f8] 'insert-date)	;forward reference
(global-set-key [f9] 'ispell-buffer)
(global-set-key [f10] 'byte-compile-file) ;for .emacs, .gnus etc.
(global-set-key [f11] 'auto-fill-mode)
(global-set-key [f12] 'font-lock-mode)
(global-unset-key "\M-g")
(global-set-key "\M-g" 'goto-line)
(global-unset-key "\M-n")
(global-set-key "\M-n" 'make-frame-command) ; Mozilla's influence ;-)
(global-set-key "\C-cl" 'region-length)	;forward reference
;(global-set-key "\C-cp" 'cperl-perldoc)
(global-set-key "\C-cd" 'dos2unix)	;forward reference


;; DEFAULTS

; Highlight marked region
(transient-mark-mode t)

; Auto fill in all major modes
(setq-default auto-fill-function 'do-auto-fill) 

; Automagically read compressed files
(auto-compression-mode 1)

; Automagically save bookmarks
(setq bookmark-save-flag 1)

; Make mouse yank at point
(setq mouse-yank-at-point t)

; Make searches case-insensitive
(setq case-fold-search t)

; Man page pushiness
(setq Man-notify-method 'pushy)

; Parenthesis matching
(show-paren-mode 1)

; Show line and column numbers in modeline
(line-number-mode t)
(column-number-mode t)

; Font lock in all major modes
(global-font-lock-mode 1)
(setq font-lock-maximum-decoration t)

; Scroll line by line
(setq scroll-step 1)

; Don't add newlines to end of buffer when scrolling
(setq next-line-add-newlines nil)

; Don't modify eol's
(setq inhibit-eol-conversion t)

; 'y' for 'yes', 'n' for 'no'
(fset 'yes-or-no-p 'y-or-n-p)

; Access system clipboard
;(setq x-select-enable-clipboard t)

;; CUSTOM FACES

; Region higlighting
(set-face-foreground 'region "black")
(set-face-background 'region "grey60")

; Paren matching
(set-face-foreground 'show-paren-match-face "black")
(set-face-background 'show-paren-match-face "seagreen")
(set-face-foreground 'show-paren-mismatch-face "black")
(set-face-background 'show-paren-mismatch-face "coral")

; Font lock faces
(set-face-foreground 'font-lock-comment-face "darkkhaki")
(set-face-foreground 'font-lock-string-face "yellowgreen")
(set-face-foreground 'font-lock-function-name-face "cornflowerblue")
(set-face-foreground 'font-lock-keyword-face "red")
(set-face-foreground 'font-lock-constant-face "cyan")
(set-face-foreground 'font-lock-type-face "antiquewhite")
(set-face-foreground 'font-lock-variable-name-face "navajowhite")
(set-face-foreground 'font-lock-builtin-face "pink")



;; MODES

; CPerl mode 
;  Make it the default perl editing mode.
; Modify the alist - back to Cperl section, breaks elsewhere
(defun modify-alist (alist-symbol key value &optional search-cdr)
  (let ((alist (symbol-value alist-symbol)))
    (while alist
      (if (eq (if search-cdr
                  (cdr (car alist))
                (car (car alist))) key)
          (setcdr (car alist) value)
        (setq alist (cdr alist))))))

(modify-alist 'interpreter-mode-alist 'perl-mode 'cperl-mode t)
(modify-alist 'auto-mode-alist        'perl-mode 'cperl-mode t)

(setq cperl-hairy t			;turn on everything
      cperl-indent-level 4
      cperl-auto-newline t
;      cperl-auto-newline-after-colon t
      cperl-continued-statement-offset 4
      cperl-brace-offset -4
      cperl-label-offset -4
      )		


; Flash paren mode (didn't have to do this in XEmacs !)
(load-library "flash-paren")
(flash-paren-mode 1)

; C-mode

(c-set-style "k&r")

;; HOOKS

; Makes more sense to make this global.
; (add-hook 'cperl-mode-hook
; 	  'lambda ()
; 	  (define-key cperl-mode-map "\C-cp" 'cperl-perldoc))

;; PACKAGES

; Gnus 5.8.4

; AuCTeX - now globally installed by Debian 2.2, doesn't need this any
; more.
;(require 'tex-site)

; BBDB
(require 'bbdb)
(bbdb-initialize 'gnus 'message 'sc)
(bbdb-insinuate-sc)
(setq bbdb-north-american-phone-numbers-p nil
      bbdb/mail-auto-create-p nil
      bbdb-quiet-about-name-mismatches t
      bbdb-notice-auto-save-file t
      bbdb-message-caching-enabled t
      bbdb-offer-save t
      )

; Mailcrypt
(load-library "mailcrypt")
(mc-setversion "gpg")			; use GPG as default
(autoload 'mc-install-write-mode "mailcrypt" nil t)
(autoload 'mc-install-read-mode "mailcrypt" nil t)
(add-hook 'mail-mode-hook 'mc-install-write-mode)


;; FUNCTION DEFINITIONS


; Insert date into buffer
(defun insert-date ()
  "Insert date at point."
  (interactive)
  (insert (format-time-string "%A, %B %e, %Y %k:%M:%S %z")))

; Compute the length of the marked region 
(defun region-length ()
  "length of a region"
  (interactive)
  (message (format "%d" (- (region-end) (region-beginning)))))

; dos2unix and unix2dos from Benjamin Rutt's .emacs

; Convert a buffer from dos ^M end of lines to unix end of lines
(defun dos2unix ()
  (interactive)
  (goto-char (point-min))
  (while (search-forward "\r" nil t) (replace-match "")))

;vice versa
(defun unix2dos ()
  (interactive)
  (goto-char (point-min))
  (while (search-forward "\n" nil t) (replace-match "\r\n")))
